Documentation
¶
Overview ¶
Provides generic function oki.DOKI wrapping WithResponses receiver functions by an oapi-codegen generated ClientWithResponses.
(C) 2025 SA6MWA Michel https://pkt.systems License: MIT
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ERR_NO_CONTENT error = fmt.Errorf("%d %s", http.StatusNoContent, http.StatusText(http.StatusNoContent))
)
Functions ¶
func DEREF ¶ added in v1.0.0
func DEREF[T any](p *T) T
Deref returns the value pointed to by p, or empty if p is nil.
func DEREFWithDefault ¶ added in v1.0.0
func DEREFWithDefault[T any](p *T, def T) T
DEREFWithDefault returns the value pointed to by p, or def if p is nil.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.